==> ra-sdk-0.0.1-20191224.022434-2-sources.jar: com/xdja/ra/bean/UpdateApply.java <==
package com.xdja.ra.bean;


/**
 * @author: ggp
 * @Date: 2019/10/22 18:23
 * @Description:
 */
public class UpdateApply {
    /**
     * 非必须 申请原因
     */
    private String applyReason;
    /**
     * 必须 更新后的证书DN
     */
    private String certDn;
    /**
     * 必须 更新后的证书有效期
     */
    private Integer certValidity;
    /**
     * 必须 待更新证书签名证书sn
     */
    private String signSn;
    /**
     * 必须 是否更新密钥
     */
    private Boolean updateKey;

    /**
     * 必须 是否更新有效期
     */
    private Boolean updateValidity;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public Boolean getUpdateKey() {
        return updateKey;
    }

    public void setUpdateKey(Boolean updateKey) {
        this.updateKey = updateKey;
    }

    public Boolean getUpdateValidity() {
        return updateValidity;
    }

    public void setUpdateValidity(Boolean updateValidity) {
        this.updateValidity = updateValidity;
    }

    @Override
    public String toString() {
        return "UpdateApply{" +
                "applyReason='" + applyReason + '\'' +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", signSn='" + signSn + '\'' +
                ", updateKey=" + updateKey +
                ", updateValidity=" + updateValidity +
                '}';
    }
}

==> ra-sdk-1.0.10-20220402.121325-2-sources.jar: com/xdja/ra/bean/UpdateApply.java <==
package com.xdja.ra.bean;


import com.xdja.pki.ra.core.util.params.NotNull;

import java.util.List;

/**
 * @author: ggp
 * @Date: 2019/10/22 18:23
 * @Description:
 */
public class UpdateApply {
    /**
     * 非必须 申请原因
     */
    private String applyReason;
    /**
     * 必须 更新后的证书DN
     */
    private String certDn;
    /**
     * 非必须 更新后的证书有效期
     */
    private Integer certValidity;
    /**
     * 非必须	模板中用户填入扩展项信息 (该参数需填入内容可通过接口或离线的方式获知)
     */
    private List<Extension> extensionList;
    /**
     * 必须 待更新证书签名证书sn
     */
    private String signSn;
    /**
     * 必须 是否更新密钥
     */
    private Boolean updateKey;
    /**
     * 必须 是否更新有效期
     */
    private Boolean updateValidity;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public List<Extension> getExtensionList() {
        return extensionList;
    }

    public void setExtensionList(List<Extension> extensionList) {
        this.extensionList = extensionList;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public Boolean getUpdateKey() {
        return updateKey;
    }

    public void setUpdateKey(Boolean updateKey) {
        this.updateKey = updateKey;
    }

    public Boolean getUpdateValidity() {
        return updateValidity;
    }

    public void setUpdateValidity(Boolean updateValidity) {
        this.updateValidity = updateValidity;
    }

    @Override
    public String toString() {
        return "UpdateApply{" +
                "applyReason='" + applyReason + '\'' +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", extensionList=" + extensionList +
                ", signSn='" + signSn + '\'' +
                ", updateKey=" + updateKey +
                ", updateValidity=" + updateValidity +
                '}';
    }
}
